onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() async{
super.onInit();
///固定垂直方向
SystemChrome.setPreferredOrientations(
isVerticalScreen() ? [DeviceOrientation.portraitUp, DeviceOrientation.portraitDown,]
: [DeviceOrientation.landscapeLeft, DeviceOrientation.landscapeRight,]
);
///状态栏背景透明
SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle.light.copyWith(statusBarColor: statusBarColor()));
///初始化sp
sp = await SharedPreferences.getInstance();
}