WidgetUtil class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

decimalFormatter → TextInputFormatter
小数
final
letterFormatter → TextInputFormatter
字母
final
numberFormatter → TextInputFormatter
整数
final
numberOrLetterFormatter → TextInputFormatter
数字或字母
final
passwordFormatter → TextInputFormatter
密码
final

Static Methods

pagedDelegate<T>(PagingController pagingController, ItemWidgetBuilder<T> itemBuilder) → PagedChildBuilderDelegate<T>
infinite_scroll_pagination
radius({double? tl, double? tr, double? br, double? bl}) → BorderRadius
text(String text, {double? size, Color? color, bool bold = false, TextOverflow? overflow, TextAlign? align, int? maxLines, bool underline = false, bool lineThrough = false}) → Text
textField(BuildContext context, TextEditingController controller, String hint, {Color? fontColor, Color? hintColor, double? fontSize, TextInputType? inputType, int maxLength = 100, TextAlign? textAlign, FocusNode? focusNode, bool? obscureText, bool? disabled, List<TextInputFormatter>? inputFormatters, Key? key, int? maxLines, double? borderWidth, Color? borderColor, double? radius, EdgeInsets? padding, bool bold = false, EdgeInsets? margin, ValueChanged<String>? onSubmit, TextInputAction? inputAction, Color? bgColor, bool autofocus = false}) → Widget
快捷创建输入框