CommonScaffold class

常用Scaffold,点击键盘外部的未消费事件区域,则让软键盘消失

Inheritance
Available extensions

Constructors

CommonScaffold({Key? key, required Widget body, bool? resizeToAvoidBottomInset = false, Color? bgColor, Widget? bottomNavigationBar, bool safeArea = true, Widget? titleBar, VoidCallback? onLeftClick, VoidCallback? onRightClick, bool paddingStatusBar = false, EdgeInsets padding = EdgeInsets.zero, bool leftTitle = false, bool boldTitle = false, bool hasDivider = true, String title = "", double? titleSize, Color? titleColor, Color? titleBarBg, Widget? titleWidget, double? titleBarHeight, String? rightImage, Widget? leftWidget, Widget? rightWidget, double? bodyWidth})
const

Properties

bgColor → Color?
final
body → Widget
final
bodyWidth → double?
final
boldTitle → bool
final
bottomNavigationBar → Widget?
final
hasDivider → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftTitle → bool
final
leftWidget → Widget?
final
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onLeftClick → VoidCallback?
下面是titlebar的属性
final
onRightClick → VoidCallback?
final
padding → EdgeInsets
final
paddingStatusBar → bool
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
resizeToAvoidBottomInset → bool?
final
rightImage → String?
final
rightWidget → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → bool
final
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
title → String
final
titleBar → Widget?
final
titleBarBg → Color?
final
titleBarHeight → double?
final
titleColor → Color?
final
titleSize → double?
final
titleWidget → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited