SuperText class

可携带一个child的Text组件

Inheritance
Available extensions

Constructors

SuperText(String text, {Key? key, ChildPosition childPosition = ChildPosition.left, Widget? child, double childSpace = 0, TextStyle? style, double? width, double? height, EdgeInsetsGeometry padding = const EdgeInsets.all(0), EdgeInsetsGeometry margin = const EdgeInsets.all(0), Color? bgColor, AlignmentGeometry? align, BorderRadiusGeometry? borderRadius, Gradient? gradient, BoxBorder? border, VoidCallback? onTap, VoidCallback? onLongPress, bool hasInkWell = false, bool spaceBetween = false, double shadow = 0, double? radius, BoxConstraints? constraints, Color? borderColor, double borderWidth = 0.0, bool disabled = false, bool expand = false})
const

Properties

align → AlignmentGeometry?
final
bgColor → Color?
final
border → BoxBorder?
final
borderColor → Color?
final
borderRadius → BorderRadiusGeometry?
final
borderWidth → double
final
child → Widget?
final
childPosition → ChildPosition
final
childSpace → double
final
constraints → BoxConstraints?
final
disabled → bool
final
expand → bool
final
gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
hasInkWell → bool
final
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry
final
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onLongPress → VoidCallback?
final
onTap → VoidCallback?
final
padding → EdgeInsetsGeometry
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → double
final
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
spaceBetween → bool
final
style → TextStyle?
final
text → String
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildChildren() → List<Widget>
buildContainer(Widget child) → Widget
buildDirection() → Widget
buildInner(Widget child) → Widget
buildSizeBox() → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited